""" A telegram bot that applies watermark on images, gifs and videos. """

from importlib.metadata import version

from telewater.main import start_bot

__version__ = version(__package__)

# AAHNIK 2021
